@@ -20,13 +20,16 @@ CacheData = tuple[str, ...]
 OnlyColumn = tuple[str, ...] | ParsedFn
 DEFAULT_MAPPINGS = {value: value for value in _SQLITETYPES}
 
-def extract_table(table_creation: str):  # pylint: disable=too-many-locals
+def extract_table(table_creation: str) -> list[Column]:  # pylint: disable=too-many-locals
     """Extract SQLite table string"""
     data = table_creation[table_creation.find('(')+1:-1]
     cols, upheld = basic_extract(table_creation)
     shlexed = list(shlex(data))
     _, paren_wrap, filtered = filter_extraction(data, shlexed)
 
+    # for efficiency, is this part efficient though?
+    # although, can SOMEONE have a million columns on a sqlite table?
+    # So, the efficiency on this blob isn't a concern.
     for column_string in filtered.split(','):
         column_shlexed = list(shlex(column_string))
         for tindex, token in enumerate(column_shlexed):
@@ -52,7 +55,7 @@ def extract_table(table_creation: str):  # pylint: disable=too-many-locals
                 name = wrap[1:-1] if wrap.startswith('(') else wrap
                 tb_index = next_+3
                 tb_col = tb_index+1
-                source_col_str = column_shlexed[tb_col+2][1:-1]
+                source_col_str = paren_wrap[f':{column_shlexed[tb_col+1]}'][1:-1]
                 sources = f"{column_shlexed[tb_index]}/{source_col_str}"
                 upheld[name][3] = sources
                 upheld[name][2] = True
@@ -312,9 +315,9 @@ def _build_select(table_name: str, # pylint: disable=too-many-arguments
     check_iter(only or ()) # type: ignore
     only_ = "*"
     if only and isinstance(only, ParsedFn):
-        only_ = only.parse_sql()
+        only_, _ = only.parse_sql()
     elif only and only != '*':
-        only_ = f"({', '.join(column_name for column_name in only)})"
+        only_ = f"{', '.join(column_name for column_name in only)}"
 
     query = f"select {only_} from {table_name}{' '+cond if cond else ''}"
     if limit:
